@@ -98,7 +98,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex_suite-1.6"));
+	setCaption(tr("segatex_suite-2.0"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -804,7 +804,7 @@ void MainWindow::notice()
 void MainWindow::about()
 {
 	QMessageBox::about(this, tr("About segatex_suite"),
-		tr("<h2>segatex_suite-1.6</h2>"
+		tr("<h2>segatex_suite-2.0</h2>"
 		"<p>Copyright &copy; 2007"
 		"<p>Shintaro Fujiwara."
 		"<p>segatex_suite is a SELinux tool"
@@ -820,6 +820,9 @@ void MainWindow::howtouse()
 		" and permissive just pushing button."
 		" You can install/update SELinux related"
 		" RPMs.You can audit2allow -m local -a."
+		" You can analize audit log."
+		" You can generate interfaced policy,by "
+		" Analize audit.log-generate policy."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push Parselines,Selpaw,Refine"
 		" one by one orderly."
