@@ -280,6 +280,8 @@ void ParseLinesMisc::analize_file_patterns()
 					lines_break += line_analized;//this adds to lines. also append can be used
 				}
 // it should have space otherwise getattr_dir_perms and r_dir_perms would collide
+// When refpolicy updated...
+// please copy lines what outputed data i.e. obj_perm_sets_analized_ready,txt by both obj perm sets button and misc patterns buttons.
 lines_break.gres(" dir_file_class_set","{ dir file lnk_file sock_file fifo_file chr_file blk_file }");
 lines_break.gres(" file_class_set","{ file lnk_file sock_file fifo_file chr_file blk_file }");
 lines_break.gres(" notdevfile_class_set","{ file lnk_file sock_file fifo_file }");
@@ -368,6 +370,7 @@ lines_break.gres(" append_fifo_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_fifo_file_perms","{ getattr write append lock ioctl }");
 lines_break.gres(" rw_fifo_file_perms","{ getattr read write append ioctl lock }");
 lines_break.gres(" create_fifo_file_perms","{ getattr create }");
+lines_break.gres(" rename_fifo_file_perms","{ getattr rename }");
 lines_break.gres(" delete_fifo_file_perms","{ getattr unlink }");
 lines_break.gres(" manage_fifo_file_perms","{ create getattr setattr read write append rename link unlink ioctl lock }");
 lines_break.gres(" relabelfrom_fifo_file_perms","{ getattr relabelfrom }");
@@ -379,8 +382,9 @@ lines_break.gres(" read_sock_file_perms","{ getattr read }");
 lines_break.gres(" write_sock_file_perms","{ getattr write append }");
 lines_break.gres(" rw_sock_file_perms","{ getattr read write append }");
 lines_break.gres(" create_sock_file_perms","{ getattr create }");
+lines_break.gres(" rename_sock_file_perms","{ getattr rename }");
 lines_break.gres(" delete_sock_file_perms","{ getattr unlink }");
-lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock }");
+lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock append }");
 lines_break.gres(" relabelfrom_sock_file_perms","{ getattr relabelfrom }");
 lines_break.gres(" relabelto_sock_file_perms","{ getattr relabelto }");
 lines_break.gres(" relabel_sock_file_perms","{ getattr relabelfrom relabelto }");
@@ -630,6 +634,7 @@ lines_break.gres(" append_fifo_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_fifo_file_perms","{ getattr write append lock ioctl }");
 lines_break.gres(" rw_fifo_file_perms","{ getattr read write append ioctl lock }");
 lines_break.gres(" create_fifo_file_perms","{ getattr create }");
+lines_break.gres(" rename_fifo_file_perms","{ getattr rename }");
 lines_break.gres(" delete_fifo_file_perms","{ getattr unlink }");
 lines_break.gres(" manage_fifo_file_perms","{ create getattr setattr read write append rename link unlink ioctl lock }");
 lines_break.gres(" relabelfrom_fifo_file_perms","{ getattr relabelfrom }");
@@ -641,8 +646,9 @@ lines_break.gres(" read_sock_file_perms","{ getattr read }");
 lines_break.gres(" write_sock_file_perms","{ getattr write append }");
 lines_break.gres(" rw_sock_file_perms","{ getattr read write append }");
 lines_break.gres(" create_sock_file_perms","{ getattr create }");
+lines_break.gres(" rename_sock_file_perms","{ getattr rename }");
 lines_break.gres(" delete_sock_file_perms","{ getattr unlink }");
-lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock }");
+lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock append }");
 lines_break.gres(" relabelfrom_sock_file_perms","{ getattr relabelfrom }");
 lines_break.gres(" relabelto_sock_file_perms","{ getattr relabelto }");
 lines_break.gres(" relabel_sock_file_perms","{ getattr relabelfrom relabelto }");
@@ -853,6 +859,7 @@ lines_break.gres(" append_fifo_file_perms","{ getattr append lock ioctl }");
 lines_break.gres(" write_fifo_file_perms","{ getattr write append lock ioctl }");
 lines_break.gres(" rw_fifo_file_perms","{ getattr read write append ioctl lock }");
 lines_break.gres(" create_fifo_file_perms","{ getattr create }");
+lines_break.gres(" rename_fifo_file_perms","{ getattr rename }");
 lines_break.gres(" delete_fifo_file_perms","{ getattr unlink }");
 lines_break.gres(" manage_fifo_file_perms","{ create getattr setattr read write append rename link unlink ioctl lock }");
 lines_break.gres(" relabelfrom_fifo_file_perms","{ getattr relabelfrom }");
@@ -864,8 +871,9 @@ lines_break.gres(" read_sock_file_perms","{ getattr read }");
 lines_break.gres(" write_sock_file_perms","{ getattr write append }");
 lines_break.gres(" rw_sock_file_perms","{ getattr read write append }");
 lines_break.gres(" create_sock_file_perms","{ getattr create }");
+lines_break.gres(" rename_sock_file_perms","{ getattr rename }");
 lines_break.gres(" delete_sock_file_perms","{ getattr unlink }");
-lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock }");
+lines_break.gres(" manage_sock_file_perms","{ create getattr setattr read write rename link unlink ioctl lock append }");
 lines_break.gres(" relabelfrom_sock_file_perms","{ getattr relabelfrom }");
 lines_break.gres(" relabelto_sock_file_perms","{ getattr relabelto }");
 lines_break.gres(" relabel_sock_file_perms","{ getattr relabelfrom relabelto }");
@@ -914,4 +922,3 @@ lines_break.gres(" can_exec","allow $1 $2:file { rx_file_perms execute_no_trans
 	}
 	file_w.close();    
 }//end-misc_patterns
-ParseLinesMisc::~ParseLinesMisc(){}
